==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/default_pre_login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";?>
<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body>

<?php
if (isset($error)) {
?>
<table width="770" border="0" cellspacing="0" cellpadding="4">
	<tr>
		<tr>
			<td class="txt_error">
				<?php
				echo "<b>" . $lang['arr_error_title'] . "</b><br />";
				foreach($error as $key => $i):
				echo $lang['arr_error'][$i[1]];
				if (isset($i[2])) {
				    echo ": " . $i[2];
				}
				echo "<br />";
				endforeach;
				?>
			</td>
		</tr>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />
<?php
}
?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<?php echo $content;?>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<hr />
		</td>
	</tr>
	<tr>
		<td align="center">
			<table border="0" cellspacing="12" cellpadding="0">

				<tr>
					<td class="txt_breadcrumb" valign="middle">
						<a href="http://www.barnraiser.org/aroundme/" title="aroundme homepage"><img src="<?php echo $templatePath;?>img/am_base.png" width="102" height="80" alt="" border="0" /></a><br />
					</td>

					<td class="txt_breadcrumb" valign="middle" align="left">
						aroundme version 0.2.2<br />
						W3C XHTML validated<br />
						W3C CSS validated<br />
					</td>
					<td class="txt_footer" valign="middle">
						<a href="http://www.barnraiser.org/" title="barnraiser homepage"><img src="<?php echo $templatePath;?>img/br_base.png" width="77" height="80" alt="" border="0" /></a><br />
					</td>
					<td class="txt_breadcrumb" valign="middle" align="left">
						Please consider<br />donating to<br />barnraiser.<br />
					</td>
					<td align="center">
						<a href="http://www.barnraiser.org/membership/" title="join and contribute!"><img src="<?=$templatePath;?>img/donate.png" border="0" alt="" /></a><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</body>
</html>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/default_pre_login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<?php echo "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";?>
<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body>

<?php
if (isset($log[0])) {
?>
<table width="770" border="0" cellspacing="0" cellpadding="4">
	<?php
	foreach($log as $key => $i):
		if (isset($i[0])) {
			unset($error);
			if (isset($error_handling) && $error_handling>0 && isset($i[1])) {
				$error = $lang['arr_error'][$i[0]] . ": " . $i[2] . "<br />";
			}
			elseif (empty($i[1])) {
				$error = $lang['arr_error'][$i[0]] . "<br />";
			}
		}
		
		if (isset($error)) {
	?>
	<tr>
		<td class="txt_error">
			<?php echo $error;?>
		</td>
	</tr>
	<?
	}
	endforeach;
	?>
</table>
<?php
}
?>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<?php echo $content;?>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<hr />
		</td>
	</tr>
	<tr>
		<td align="center">
			<table border="0" cellspacing="12" cellpadding="0">

				<tr>
					<td class="txt_breadcrumb" valign="middle">
						<a href="http://www.barnraiser.org/aroundme/" title="aroundme homepage"><img src="<?php echo $templatePath;?>img/am_base.png" width="102" height="80" alt="" border="0" /></a><br />
					</td>

					<td class="txt_breadcrumb" valign="middle" align="left">
						aroundme version 0.2.2<br />
						W3C XHTML validated<br />
						W3C CSS validated<br />
					</td>
					<td class="txt_footer" valign="middle">
						<a href="http://www.barnraiser.org/" title="barnraiser homepage"><img src="<?php echo $templatePath;?>img/br_base.png" width="77" height="80" alt="" border="0" /></a><br />
					</td>
					<td class="txt_breadcrumb" valign="middle" align="left">
						Please consider<br />donating to<br />barnraiser.<br />
					</td>
					<td align="center">
						<a href="http://www.barnraiser.org/membership/" title="join and contribute!"><img src="<?=$templatePath;?>img/donate.png" border="0" alt="" /></a><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</body>
</html>
